@@ -23,9 +23,12 @@ class EasyPreProcessing:
         clustering (Clustering): 
         dates (DateTimeFeatures): 
     """
-    def __init__(self, path):
+    def __init__(self, path=None, data=None):
         self.path = path
-        self.dataset = self.load_dataframe(path)
+        if path != None or path != '':
+            self.dataset = self.load_dataframe(path)
+        else:
+            self.dataset = data
         self.output = None
         self.categorical = CategoryFeatures(self)
         self.numerical = NumericFeatures(self)
@@ -73,7 +76,7 @@ prep.missing_values
 prep.categorical.impute()
 prep.numerical.impute()
 prep.categorical.encode()
-prep.correction()
+prep.correlation()
 prep.standardize()
 X_train, X_test, y_train, y_test = prep.split()
 </code>
@@ -124,7 +127,7 @@ X_train, X_test, y_train, y_test = prep.split()
 <td>remove_blank()</td><td>Remove empty/blank columns</td>
 </tr>
 <tr>
-<td>correction()</td><td>Display correction heatmap</td>
+<td>correlation()</td><td>Display correlation heatmap</td>
 </tr>
 <tr>
 <td>standardize()</td><td>Standardize entire dataset except dependent variable</td>
@@ -166,7 +169,7 @@ X_train, X_test, y_train, y_test = prep.split()
         self.dataset[self.__get_unique_numerical()] = pd.DataFrame(StandardScaler().fit_transform(self.dataset[self.__get_unique_numerical()]))
         print('Dataset has been standardized.')
     
-    def correction(self):
+    def correlation(self):
         sns.heatmap(self.dataset.corr())
     
     def remove_blank(self):
